Package: qsmooth
Title: Smooth quantile normalization
Version: 1.28.0
Authors@R: c(
    person(c("Stephanie", "C."), "Hicks", role = c("aut", "cre"), 
		email = "shicks19@jhu.edu", 
		comment = c(ORCID = "0000-0002-7858-0231")),
    person("Kwame", "Okrah", role = "aut"),
    person("Koen", "Van den Berge", role = "ctb"),
    person("Hector", "Corrada Bravo", role = "aut", 
		comment = c(ORCID = "0000-0002-1255-4444")), 
    person("Rafael", "Irizarry", role = "aut", 
		comment = c(ORCID = "0000-0002-3944-4309")))
Imports: SummarizedExperiment, utils, sva, stats, methods, graphics,
        Hmisc
Depends: R (>= 4.0)
Suggests: bodymapRat, quantro, knitr, rmarkdown, BiocStyle, testthat
VignetteBuilder: knitr
RoxygenNote: 7.1.1
Encoding: UTF-8
License: GPL-3
Description: Smooth quantile normalization
    is a generalization of quantile normalization,
    which is average of the two types of assumptions
    about the data generation process: quantile
    normalization and quantile normalization between
    groups.
biocViews: Normalization, Preprocessing, MultipleComparison,
        Microarray, Sequencing, RNASeq, BatchEffect
git_url: https://git.bioconductor.org/packages/qsmooth
git_branch: RELEASE_3_23
git_last_commit: d84931f
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 00:02:24 UTC; biocbuild
Author: Stephanie C. Hicks [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-7858-0231>),
  Kwame Okrah [aut],
  Koen Van den Berge [ctb],
  Hector Corrada Bravo [aut] (ORCID:
    <https://orcid.org/0000-0002-1255-4444>),
  Rafael Irizarry [aut] (ORCID: <https://orcid.org/0000-0002-3944-4309>)
Maintainer: Stephanie C. Hicks <shicks19@jhu.edu>
