# Generated by roxygen2: do not edit by hand

export(qsmooth)
export(qsmoothGC)
export(qsmoothPlotWeights)
export(qstats)
exportClasses(qsmooth)
exportMethods(qsmoothData)
exportMethods(qsmoothWeights)
import(methods)
importFrom(Hmisc,cut2)
importFrom(SummarizedExperiment,assay)
importFrom(SummarizedExperiment,assays)
importFrom(graphics,abline)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(stats,ave)
importFrom(stats,model.matrix)
importFrom(stats,runmed)
importFrom(sva,ComBat)
importFrom(utils,head)
importFrom(utils,tail)
